doResampling<-function(vari="evi",TLUT,projinfo) {

  # always 1km
  resolution <- 1

  Sys.setenv(MRTDATADIR=mpath)

  # resampling all files
  # loop through TLUT
  for (i in 1:(length(TLUT)/6)) {

   if ((length(TLUT)/6)==1) {
    if (TLUT[1]<10) H <- paste("0",TLUT[1],sep="") else H <- TLUT[1]
    if (TLUT[2]<10) V <- paste("0",TLUT[2],sep="") else V <- TLUT[2]
   } else {
    if (TLUT[i,1]<10) H <- paste("0",TLUT[i,1],sep="") else H <- TLUT[i,1]
    if (TLUT[i,2]<10) V <- paste("0",TLUT[i,2],sep="") else V <- TLUT[i,2]
   }

   Files <- list.files(mpath,paste(vari,"_1km_MOD09A1.*h",H,"v",V,".*hdf",sep=""))

   for (File in Files) {
    tmp        <- strsplit(File,split="_")
    prefix     <- paste(tmp[[1]][1],"_",strsplit(tmp[[1]][3],split="hdf"),sep="")
    outputfile <- paste(prefix,resolution,"km.hdf",sep="") 

    # check if result is already there
    if ( file.exists(outputfile) ) {
     print(paste("File ",File," reprojected. Skipping.",sep=""))
     next
    }
 
    # resample
    # create parameter file
    cat(paste("INPUT_FILENAME = ",File,"\n",sep=""),file="parameter.prm")
    cat(paste("OUTPUT_FILENAME = ",outputfile,"\n",sep=""),file="parameter.prm",append=TRUE)
    cat("SPECTRAL_SUBSET = ( 1 )\n",file="parameter.prm",append=TRUE)
    cat(paste("OUTPUT_PROJECTION_TYPE = GEO\n",sep=""),file="parameter.prm",append=TRUE)

    # from MRT_Users_Manual.doc Page 51 8/26/2009:
    #OUTPUT_PROJECTION_PARAMETERS = ( p1 p2 ... p15 )
    # This array contains the 15 output projection parameter values. 
    # This field is optional; by default, all projection parameter values will be set to zero.
    # (An exception is UTM: when the first two UTM projection parameters are zero, 
    # the projection will default to the scene center.) 
    # Projection parameter values are floating point; 
    # integer values will automatically be converted to floating point. 
    # If there are fewer than 15 projection
    # parameter values specified, the remaining values will be set to zero.
    # 9 See Appendix C for more information on projection parameters. 
    # cat(paste("OUTPUT_PROJECTION_PARAMETERS = (6370000.0 6370000.0 ",projinfo$moadstandlats[1]," ",projinfo$moadstandlats[2]," ",projinfo$moadstandlons [1]," ",projinfo$moadknownlat," 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0)\n",sep=""),file="parameter.prm",append=TRUE)

    cat("DATUM = NoDatum\n",file="parameter.prm",append=TRUE)
    cat(paste("OUTPUT_PIXEL_SIZE = ",spacing,"\n",sep=""),file="parameter.prm",append=TRUE)

    if (which(Files==File)==1) {
     # do projection
     sysout <- system(paste(mrt,"/bin/resample -p parameter.prm",sep=""),intern=TRUE)

     # fill up TLUT:
     # parse resample output
     # get tile
     sysouttemp <- strsplit(sysout[grep("input_filename:",sysout)],"\\.")[[1]][3]
     H          <- as.numeric(strsplit(strsplit(sysouttemp,"v")[[1]][1],"h")[[1]][2])
     V          <- as.numeric(strsplit(sysouttemp,"v")[[1]][2])
     # get LL values for resolution
     LLlat      <- as.numeric(strsplit(sysout[grep("LL:",sysout)][3]," ")[[1]][7])
     LLlon      <- as.numeric(strsplit(sysout[grep("LL:",sysout)][3]," ")[[1]][8])
     # get UR values for resolution
     URlat      <- as.numeric(strsplit(sysout[grep("UR:",sysout)][3]," ")[[1]][7])
     URlon      <- as.numeric(strsplit(sysout[grep("UR:",sysout)][3]," ")[[1]][8])

     # modify TLUT
     if ((length(TLUT)/6)==1) {
      # tile table row contains: v,h,LAT (LL),LON (LL), LAT (UR), LON (UR)
      TLUT[3] <- LLlat;TLUT[4]<-LLlon;TLUT[5]<-URlat;TLUT[6]<-URlon
     } else {
      # tile table row contains: v,h,LAT (LL),LON (LL), LAT (UR), LON (UR)
      TLUT[i,3] <- LLlat;TLUT[i,4]<-LLlon;TLUT[i,5]<-URlat;TLUT[i,6]<-URlon
     }
     
     print(TLUT)
    } else {
     # do projection
     system(paste(mrt,"/bin/resample -p parameter.prm",sep=""))
    }
    
   }
  }

  return(TLUT)
}
